# RawToken

Raw token
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token** | **str** | token string | 
**session** | **str** | Unique identifier | [optional] [readonly] 
**time_validity** | [**TimeValidity**](TimeValidity.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


